@@ -10,8 +10,8 @@ def subscribe(option, cb):
   from kafka import KafkaConsumer
   import requests
 
-  kafka_url = option.kafka_url or '52.77.249.163:9092'
-  api_url = option.api_url or 'http://18.141.231.146:8000'
+  kafka_url = option["kafka_url"] or '52.77.249.163:9092'
+  api_url = option["api_url"] or 'http://18.141.231.146:8000'
 
   print('Krit naja')
   print('kafka_url: ', kafka_url)
